import os
import sys
import shutil
import pandas as pd
from thyrsis.log import logger
from thyrsis.database import sqlite
from thyrsis.settings import Settings

def convert_names(s, none_values=["inconnu"]):
    # on ne conserve que la première partie avant tout blanc
    if not s:
        return None
    v = s.split(" ")[0]
    if v in none_values:
        return None
    else:
        indx = len(v)
        for n in [str(x) for x in range(10)]:
            if n in v:
                indx = min(indx, v.index(n))
        if indx < len(v):
            w = v[0 : indx] + "-" + v[indx : ]
        else:
            w = v
        return w.replace("aéro", "")

def convert_radionuclides(sitesdb):

    conn = sqlite.connect(sitesdb)
    cur = conn.cursor()
    radionuclides_file = os.path.join(os.path.dirname(os.path.abspath(sitesdb)), "radionuclides.csv")

    columns = [x[1] for x in cur.execute("PRAGMA table_info(elements_chimiques)").fetchall()]
    values = cur.execute("SELECT %s FROM elements_chimiques ORDER BY nom"%(', '.join(columns))).fetchall()
    columns = [x.replace("nombre_de_masses", "nombre_de_masse") for x in columns]
    df = pd.DataFrame(values, columns=columns)
    df.drop_duplicates(["periode", "masse_atomique", "activite_specifique"], inplace=True)
    df.loc[:, "nom"] = df.nom.apply(lambda s: convert_names(s, ["RDX", "inconnu"]))
    df = df.loc[df["nom"].notna()]
    df = df.reindex(columns=columns[1:])
    df.numero_atomique = df.numero_atomique.apply(lambda v: int(float(v)))
    df.nombre_de_masse = df.nombre_de_masse.apply(lambda v: int(float(v)))
    # ajout de HTO comme copie de H-3
    hto = df[df.nom=="H-3"].copy()
    hto.loc[:, "nom"] = hto.nom.str.replace("H-3", "HTO")
    radionuclides = df.append(hto).sort_values(by=["nom"])
    radionuclides.to_csv(
        radionuclides_file, encoding="utf-8", index=False, header=True, sep=";"
    )

if __name__ == "__main__":

    logger.enable_console(True)

    if len(sys.argv) == 2 and sys.argv[1] in ["-h","--help"]:
        help(sys.modules[__name__])
        exit(0)

    convert_radionuclides(str(Settings().value("General", "defaultSite")))
